@@ -8,12 +8,8 @@ SPDX-License-Identifier: GPL-2.0-or-later
 #include "../x11locker.h"
 // Qt
 #include <QWindow>
-#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
 #include <private/qtx11extras_p.h>
-#else
-#include <QX11Info>
-#endif
-#include <QtTest>
+#include <QTest>
 // xcb
 #include <xcb/xcb.h>
 
